==> postLDAPadmin_user-2.20.tar.gz: user/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * index.php
 * 桼
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.3 $
 * $Date: 2010/06/22 05:37:35 $
 *
 **********************************************************/

include_once("initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
print <<<EOD
<form method="post" action="index.php" name="acc_mod_mf">
<center>
<table class="login">
    <tr>
        <td class="key1">桼̾</td>
        <td class="login"><input type="text" size=26 name="user" maxlength="256"></td>
    </tr>
    <tr>
        <td class="key1">ѥ</td>
        <td class="login"><input type="password" name="passwd" maxlength="8"></td>
    </tr>
</table>
<br>
<input type="submit" name="login" value="" class="login_btn">
</center>
</form>
EOD;
    }

    /***********************************************************
     * ̵֤ɽ
     **********************************************************/
    function display_tab() {
    }

    /***********************************************************
     * Ȥ̵ɽ
     **********************************************************/
    function display_logout() {
    }

};

/***********************************************************
 * 
 **********************************************************/
/* 󥹥󥹺 */
$pg  = new my_page();

/* $topdir$basedirΥå */
url_search();

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

$url_data["script"] = "postldapadmin";

/* ɹ */
if (read_web_conf($url_data["script"]) === FALSE) {
    $sys_err = TRUE;
    $err_msg = "Ǥޤ";
    $pg->display(NULL);
    exit (1);
}

/* Ź沽Υѥ򥻥å */
$admkey_file = $basedir . ETCDIR . $domain . "/" . ADMKEY;

/***********************************************************
 * main
 **********************************************************/

/* ʬ */
if (isset($_POST["login"]) === TRUE) {

    /* 桼̾Υå */
    if ($_POST["user"] != "" &&
        check_search_name($_POST["user"]) === TRUE &&
        check_passwd($_POST["passwd"], MINPASSWD, MAXPASSWD) === TRUE) {
        /* åå& */
        $chk_mode = GENUSER;

        if (sess_start($_POST["user"], $_POST["passwd"], $sesskey, $chk_mode) === TRUE) {
            result_log(":OK:󤷤ޤ");
            if (read_tab_conf(USERTABCONF) === FALSE) {
                $sys_err = TRUE;
                $pg->display(NULL);
                exit (1);
            }
            $script = key($tab_conf);
            $tab = key($tab_conf[$script][0]);
            dgp_location($script . "/" . $tab . "/index.php");
            exit (0);
        } 
        if (isset($env["ldap_server_down"])) {
            result_log("NULL LDAP³:NG:" . $err_msg);
            $err_msg = "桼Ǥޤ";
        } else {
            $err_msg = "桼̾⤷ϥѥɤְäƤޤ";
        }

    } else {
        $err_msg = "桼̾⤷ϥѥɤޤ";
    }
}
if (isset($_GET["e"]) === TRUE) {
    if ($_GET["e"] == 1) {
        $err_msg = "å̵Ǥ";
    }
    if ($_GET["e"] == 2) {
        $err_msg = "ˡǤ";
    }
    if ($_GET["e"] == 3) {
        $err_msg = "桼Ǥޤ";
    }
}

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> postLDAPadmin_user-3.00.tar.gz: user/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * index.php
 * 桼
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.14 $
 * $Date: 2012/09/19 03:22:42 $
 *
 **********************************************************/

include_once("initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");

/********************************************************
 * ƥڡȤ
*********************************************************/
define("OPERATION_LOGIN", "Login");
define("TMPLFILE", "user_login.tmpl");

/***********************************************************
 * 
 **********************************************************/

/*  */
$tag["<<TITLE>>"]      = "";
$tag["<<JAVASCRIPT>>"] = "";
$tag["<<MESSAGE>>"]    = "";

/* $topdir$basedirΥå */
url_search();

/* ɥᥤ */
$domain = $_SERVER['DOMAIN'];

$url_data["script"] = "postldapadmin";

/* ɹ */
if (read_web_conf($url_data["script"]) === FALSE) {
    syserr_display();
    exit (1);
}

/* åեɹ */
if (make_msgarr(MESSAGEFILE) === FALSE) {
    syserr_display();
    exit (1);
}

/* Ź沽Υѥ򥻥å */
$admkey_file = $basedir . ETCDIR . $domain . "/" . ADMKEY;

/***********************************************************
 * main
 **********************************************************/

/* ʬ */
if (isset($_POST["login"]) === TRUE) {

    /* 桼̾Υå */
    if ($_POST["user"] != "" &&
        check_search_name($_POST["user"]) === TRUE &&
        check_passwd($_POST["passwd"], MINPASSWD, MAXPASSWD) === TRUE) {
        /* åå& */
        $chk_mode = GENUSER;

        if (sess_start($_POST["user"], $_POST["passwd"], $sesskey, $chk_mode) === TRUE) {
            result_log(OPERATION_LOGIN . ":OK:" . $msgarr['05006'][LOG_MSG]);
            if (read_tab_conf(USERTABCONF) === FALSE) {
                syserr_display();
                exit (1);
            }
            $script = key($tab_conf);
            $tab = key($tab_conf[$script][0]);
            dgp_location($script . "/" . $tab . "/index.php");
            exit (0);
        }
        if (isset($env["ldap_server_down"])) {
            result_log(OPERATION_LDAP_CONNECTION . ":NG:" . $log_msg);
            $err_msg = $msgarr['06002'][SCREEN_MSG];
            $log_msg = $msgarr['06002'][LOG_MSG];
        } else {
            $err_msg = $msgarr['06003'][SCREEN_MSG];
            $log_msg = $msgarr['06003'][LOG_MSG];
        }

    } else {
        $err_msg = $msgarr['06004'][SCREEN_MSG];
        $log_msg = $msgarr['06004'][LOG_MSG];
    }
}
if (isset($_GET["e"]) === TRUE) {
    if ($_GET["e"] == 1) {
        $err_msg = $msgarr['06005'][SCREEN_MSG];
        $log_msg = $msgarr['06005'][LOG_MSG];
    }
    if ($_GET["e"] == 2) {
        $err_msg = $msgarr['06006'][SCREEN_MSG];
        $log_msg = $msgarr['06006'][LOG_MSG];
    }
    if ($_GET["e"] == 3) {
        $err_msg = $msgarr['06002'][SCREEN_MSG];
        $log_msg = $msgarr['06002'][LOG_MSG];
    }
}

/***********************************************************
 * ɽ
 **********************************************************/

/*   */
$tag["<<TITLE>>"] = $web_conf["global"]["titlename"];
if (empty($err_msg)) {
    $tag["<<MESSAGE>>"] = "&nbsp;";
} else {
    $tag["<<MESSAGE>>"] = $err_msg;
}
$tag["<<JAVASCRIPT>>"] = <<<EOD
<script type="text/javascript">
<!--
function msgConfirm(msg) {
        return(window.confirm(msg));
}

function dgpSubmit(url) {
    document.common.action = url;
    document.common.submit();
}
// -->
</script>
EOD;

/* ڡν */
$ret = display(TMPLFILE, $tag, array(), "", "");
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
